# Example

```csharp
using FitConnect;
using FitConnect.Models;
```

## The easy way to call the FitConnect API

```csharp
async Task AbstractCall() {
    var client = new Client(
        FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development),
        "clientId", "clientSecret");

    var success = await client.SendSubmissionAsync(new Submission());

    var submissions = await client.GetSubmissionsAsync("destinationId");

    foreach (var submission in submissions) Console.WriteLine(submission.Id);
}

```

## The more verbose way to call the FitConnect API

### The Fluent Sender Api call
```csharp
void FluentSenderCall() {
    var client =
        new Client(FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development),
            logger: _logger);
    client.Sender
        .Authenticate(clientId, clientSecret)
        .CreateSubmission(new Submission())
        .UploadAttachments(new List<Attachment>())
        .SendSubmission(new Metadata(), new Data());
}
```

### Here to call the **Sender** interface

```csharp
void DetailSenderCall() {
    var sender =
        new Sender(
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development));
    sender.CreateSubmissionDto(new Submission());
    /*
     ....
     */
}

```

### Here to call the **Subscriber** interface

```csharp


async Task DetailSubscriberCall() {
    var subscriber =
        new Subscriber(
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development));
    var submissions = await subscriber.GetSubmissionsAsync("destinationId");
    /*
     ....
     */
}

```